BEGIN {
    ON  = 1
    OFF = 0
    PROTEIN_ATOMTYPES = "CNOSHXM"         
    # PROTEIN_ATOMTYPES should be set to the same string
    # as ATOMTYPE is in autogrid.h; make sure this
    # is a copy of its value there.
    ALL_TYPES = "CANOSPH"        #ALL_TYPES = "CANOSPHfFcbIM"
    NUM_TYPES = length(ALL_TYPES)
    for (i=1; i <= NUM_TYPES; i++) {
      n[substr(ALL_TYPES, i,1)] = 0
    }

    #
    # Free energy model 140n s coefficients:
    #
    FE_vdW_coeff   = 0.1485
    FE_estat_coeff = 0.1146
    FE_hbond_coeff = 0.0656
    FE_tors_coeff  = 0.3113
    FE_desol_coeff = 0.1711

    # AutoDock Binding Free Energy Model 140n
    # Uses the C.A.Lig.only solvation model, i.e.
    # aliphatic (C) and aromatic (A) carbon atoms only
    #
    SolVol[ "C" ] = 12.77
    SolVol[ "A" ] = 10.80
    SolVol[ "N" ] =  0.
    SolVol[ "O" ] =  0.
    SolVol[ "H" ] =  0.

    #SolPar[ "C" ] =  0.6844
    #SolPar[ "A" ] =  0.1027

    SolPar[ "C" ] =  4.0 * FE_desol_coeff
    SolPar[ "A" ] =  0.6 * FE_desol_coeff
    SolPar[ "N" ] =  0.
    SolPar[ "O" ] =  0.
    SolPar[ "H" ] =  0.

    SolCon[ "C" ] =  0.
    SolCon[ "A" ] =  0.
    SolCon[ "N" ] =  0.
    SolCon[ "O" ] =  0.236
    SolCon[ "H" ] =  0.118

    Rij[ "lj" "C" "C" ] = 4.00
    Rij[ "lj" "C" "N" ] = 3.75
    Rij[ "lj" "C" "O" ] = 3.60
    Rij[ "lj" "C" "P" ] = 4.10
    Rij[ "lj" "C" "S" ] = 4.00
    Rij[ "lj" "C" "H" ] = 3.00
    Rij[ "lj" "C" "f" ] = 2.65
    Rij[ "lj" "C" "F" ] = 3.54
    Rij[ "lj" "C" "c" ] = 4.04
    Rij[ "lj" "C" "b" ] = 4.17
    Rij[ "lj" "C" "I" ] = 4.36
    Rij[ "lj" "C" "M" ] = 2.79
    Rij[ "lj" "C" "X" ] = 3.75

    Rij[ "lj" "N" "C" ] = 3.75
    Rij[ "lj" "N" "N" ] = 3.50
    Rij[ "lj" "N" "O" ] = 3.35
    Rij[ "lj" "N" "P" ] = 3.85
    Rij[ "lj" "N" "S" ] = 3.75
    Rij[ "lj" "N" "H" ] = 2.75
    Rij[ "lj" "N" "f" ] = 2.40
    Rij[ "lj" "N" "F" ] = 3.29
    Rij[ "lj" "N" "c" ] = 3.79
    Rij[ "lj" "N" "b" ] = 3.92
    Rij[ "lj" "N" "I" ] = 4.11
    Rij[ "lj" "N" "M" ] = 2.54
    Rij[ "lj" "N" "X" ] = 3.50

    Rij[ "lj" "O" "C" ] = 3.60
    Rij[ "lj" "O" "N" ] = 3.35
    Rij[ "lj" "O" "O" ] = 3.20
    Rij[ "lj" "O" "P" ] = 3.70
    Rij[ "lj" "O" "S" ] = 3.60
    Rij[ "lj" "O" "H" ] = 2.60
    Rij[ "lj" "O" "f" ] = 2.25
    Rij[ "lj" "O" "F" ] = 3.15
    Rij[ "lj" "O" "c" ] = 3.65
    Rij[ "lj" "O" "b" ] = 3.77
    Rij[ "lj" "O" "I" ] = 3.96
    Rij[ "lj" "O" "M" ] = 2.39
    Rij[ "lj" "O" "X" ] = 3.35

    Rij[ "lj" "P" "C" ] = 4.10
    Rij[ "lj" "P" "N" ] = 3.85
    Rij[ "lj" "P" "O" ] = 3.70
    Rij[ "lj" "P" "P" ] = 4.20
    Rij[ "lj" "P" "S" ] = 4.10
    Rij[ "lj" "P" "H" ] = 3.10
    Rij[ "lj" "P" "f" ] = 2.75
    Rij[ "lj" "P" "F" ] = 3.65
    Rij[ "lj" "P" "c" ] = 4.14
    Rij[ "lj" "P" "b" ] = 4.27
    Rij[ "lj" "P" "I" ] = 4.46
    Rij[ "lj" "P" "M" ] = 2.89
    Rij[ "lj" "P" "X" ] = 3.85

    Rij[ "lj" "S" "C" ] = 4.00
    Rij[ "lj" "S" "N" ] = 3.75
    Rij[ "lj" "S" "O" ] = 3.60
    Rij[ "lj" "S" "P" ] = 4.10
    Rij[ "lj" "S" "S" ] = 4.00
    Rij[ "lj" "S" "H" ] = 3.00
    Rij[ "lj" "S" "f" ] = 2.65
    Rij[ "lj" "S" "F" ] = 3.54
    Rij[ "lj" "S" "c" ] = 4.04
    Rij[ "lj" "S" "b" ] = 4.17
    Rij[ "lj" "S" "I" ] = 4.36
    Rij[ "lj" "S" "M" ] = 2.79
    Rij[ "lj" "S" "X" ] = 3.75

    Rij[ "lj" "H" "C" ] = 3.00
    Rij[ "lj" "H" "N" ] = 2.75
    Rij[ "lj" "H" "O" ] = 2.60
    Rij[ "lj" "H" "P" ] = 3.10
    Rij[ "lj" "H" "S" ] = 3.00
    Rij[ "lj" "H" "H" ] = 2.00
    Rij[ "lj" "H" "f" ] = 1.65
    Rij[ "lj" "H" "F" ] = 2.54
    Rij[ "lj" "H" "c" ] = 3.04
    Rij[ "lj" "H" "b" ] = 3.17
    Rij[ "lj" "H" "I" ] = 3.36
    Rij[ "lj" "H" "M" ] = 1.79
    Rij[ "lj" "H" "X" ] = 2.75

    Rij[ "lj" "f" "C" ] = 2.65
    Rij[ "lj" "f" "N" ] = 2.40
    Rij[ "lj" "f" "O" ] = 2.25
    Rij[ "lj" "f" "P" ] = 2.75
    Rij[ "lj" "f" "S" ] = 2.65
    Rij[ "lj" "f" "H" ] = 1.65
    Rij[ "lj" "f" "f" ] = 1.30
    Rij[ "lj" "f" "F" ] = 2.19
    Rij[ "lj" "f" "c" ] = 2.69
    Rij[ "lj" "f" "b" ] = 2.81
    Rij[ "lj" "f" "I" ] = 3.01
    Rij[ "lj" "f" "M" ] = 1.44
    Rij[ "lj" "f" "X" ] = 2.40

    Rij[ "lj" "F" "C" ] = 3.54
    Rij[ "lj" "F" "N" ] = 3.29
    Rij[ "lj" "F" "O" ] = 3.15
    Rij[ "lj" "F" "P" ] = 3.65
    Rij[ "lj" "F" "S" ] = 3.54
    Rij[ "lj" "F" "H" ] = 2.54
    Rij[ "lj" "F" "f" ] = 2.19
    Rij[ "lj" "F" "F" ] = 3.09
    Rij[ "lj" "F" "c" ] = 3.59
    Rij[ "lj" "F" "b" ] = 3.71
    Rij[ "lj" "F" "I" ] = 3.90
    Rij[ "lj" "F" "M" ] = 2.33
    Rij[ "lj" "F" "X" ] = 3.29

    Rij[ "lj" "c" "C" ] = 4.04
    Rij[ "lj" "c" "N" ] = 3.79
    Rij[ "lj" "c" "O" ] = 3.65
    Rij[ "lj" "c" "P" ] = 4.14
    Rij[ "lj" "c" "S" ] = 4.04
    Rij[ "lj" "c" "H" ] = 3.04
    Rij[ "lj" "c" "f" ] = 2.69
    Rij[ "lj" "c" "F" ] = 3.59
    Rij[ "lj" "c" "c" ] = 4.09
    Rij[ "lj" "c" "b" ] = 4.21
    Rij[ "lj" "c" "I" ] = 4.40
    Rij[ "lj" "c" "M" ] = 2.83
    Rij[ "lj" "c" "X" ] = 3.79

    Rij[ "lj" "b" "C" ] = 4.17
    Rij[ "lj" "b" "N" ] = 3.92
    Rij[ "lj" "b" "O" ] = 3.77
    Rij[ "lj" "b" "P" ] = 4.27
    Rij[ "lj" "b" "S" ] = 4.17
    Rij[ "lj" "b" "H" ] = 3.17
    Rij[ "lj" "b" "f" ] = 2.81
    Rij[ "lj" "b" "F" ] = 3.71
    Rij[ "lj" "b" "c" ] = 4.21
    Rij[ "lj" "b" "b" ] = 4.33
    Rij[ "lj" "b" "I" ] = 4.53
    Rij[ "lj" "b" "M" ] = 2.95
    Rij[ "lj" "b" "X" ] = 3.92

    Rij[ "lj" "I" "C" ] = 4.36
    Rij[ "lj" "I" "N" ] = 4.11
    Rij[ "lj" "I" "O" ] = 3.96
    Rij[ "lj" "I" "P" ] = 4.46
    Rij[ "lj" "I" "S" ] = 4.36
    Rij[ "lj" "I" "H" ] = 3.36
    Rij[ "lj" "I" "f" ] = 3.01
    Rij[ "lj" "I" "F" ] = 3.90
    Rij[ "lj" "I" "c" ] = 4.40
    Rij[ "lj" "I" "b" ] = 4.53
    Rij[ "lj" "I" "I" ] = 4.72
    Rij[ "lj" "I" "M" ] = 3.15
    Rij[ "lj" "I" "X" ] = 4.11

    Rij[ "lj" "M" "C" ] = 2.79
    Rij[ "lj" "M" "N" ] = 2.54
    Rij[ "lj" "M" "O" ] = 2.39
    Rij[ "lj" "M" "P" ] = 2.89
    Rij[ "lj" "M" "S" ] = 2.79
    Rij[ "lj" "M" "H" ] = 1.79
    Rij[ "lj" "M" "f" ] = 1.44
    Rij[ "lj" "M" "F" ] = 2.33
    Rij[ "lj" "M" "c" ] = 2.83
    Rij[ "lj" "M" "b" ] = 2.95
    Rij[ "lj" "M" "I" ] = 3.15
    Rij[ "lj" "M" "M" ] = 1.57
    Rij[ "lj" "M" "X" ] = 2.54

    Rij[ "lj" "X" "C" ] = 3.75
    Rij[ "lj" "X" "N" ] = 3.50
    Rij[ "lj" "X" "O" ] = 3.35
    Rij[ "lj" "X" "P" ] = 3.85
    Rij[ "lj" "X" "S" ] = 3.75
    Rij[ "lj" "X" "H" ] = 2.75
    Rij[ "lj" "X" "f" ] = 2.40
    Rij[ "lj" "X" "F" ] = 3.29
    Rij[ "lj" "X" "c" ] = 3.79
    Rij[ "lj" "X" "b" ] = 3.92
    Rij[ "lj" "X" "I" ] = 4.11
    Rij[ "lj" "X" "M" ] = 2.54
    Rij[ "lj" "X" "X" ] = 3.50

    Rij[ "lj" "C" "A" ] = Rij[ "lj" "C" "C" ]
    Rij[ "lj" "A" "C" ] = Rij[ "lj" "C" "A" ]
    Rij[ "lj" "A" "A" ] = Rij[ "lj" "C" "C" ]
    Rij[ "lj" "A" "N" ] = Rij[ "lj" "C" "N" ]
    Rij[ "lj" "A" "O" ] = Rij[ "lj" "C" "O" ]
    Rij[ "lj" "A" "S" ] = Rij[ "lj" "C" "S" ]
    Rij[ "lj" "A" "H" ] = Rij[ "lj" "C" "H" ]
    Rij[ "lj" "N" "A" ] = Rij[ "lj" "A" "N" ]
    Rij[ "lj" "O" "A" ] = Rij[ "lj" "A" "O" ]
    Rij[ "lj" "S" "A" ] = Rij[ "lj" "A" "S" ]
    Rij[ "lj" "H" "A" ] = Rij[ "lj" "A" "H" ]
    Rij[ "lj" "A" "X" ] = Rij[ "lj" "C" "X" ]
    Rij[ "lj" "X" "A" ] = Rij[ "lj" "A" "X" ]

    #
    # AutoDock Binding Free Energy Model 140n
    # New well-depths using new Solvation Model, 
    # multiplied by van der Waals coefficient, 0.1485
    #

    #
    # Well-depths prior to Solvation Model, multiplied by FE_vdW_coeff
    #
    epsij[ "lj" "C" "C" ] = 0.1500 * FE_vdW_coeff
    epsij[ "lj" "C" "N" ] = 0.1549 * FE_vdW_coeff
    epsij[ "lj" "C" "O" ] = 0.1732 * FE_vdW_coeff
    epsij[ "lj" "C" "P" ] = 0.1732 * FE_vdW_coeff
    epsij[ "lj" "C" "S" ] = 0.1732 * FE_vdW_coeff
    epsij[ "lj" "C" "H" ] = 0.0548 * FE_vdW_coeff
    epsij[ "lj" "C" "f" ] = 0.0387 * FE_vdW_coeff
    epsij[ "lj" "C" "F" ] = 0.1095 * FE_vdW_coeff
    epsij[ "lj" "C" "c" ] = 0.2035 * FE_vdW_coeff
    epsij[ "lj" "C" "b" ] = 0.2416 * FE_vdW_coeff
    epsij[ "lj" "C" "I" ] = 0.2877 * FE_vdW_coeff
    epsij[ "lj" "C" "M" ] = 0.3623 * FE_vdW_coeff
    epsij[ "lj" "C" "X" ] = 0.1549 * FE_vdW_coeff

    epsij[ "lj" "N" "C" ] = 0.1549 * FE_vdW_coeff
    epsij[ "lj" "N" "N" ] = 0.1600 * FE_vdW_coeff
    epsij[ "lj" "N" "O" ] = 0.1789 * FE_vdW_coeff
    epsij[ "lj" "N" "P" ] = 0.1789 * FE_vdW_coeff
    epsij[ "lj" "N" "S" ] = 0.1789 * FE_vdW_coeff
    epsij[ "lj" "N" "H" ] = 0.0566 * FE_vdW_coeff
    epsij[ "lj" "N" "f" ] = 0.0400 * FE_vdW_coeff
    epsij[ "lj" "N" "F" ] = 0.1131 * FE_vdW_coeff
    epsij[ "lj" "N" "c" ] = 0.2101 * FE_vdW_coeff
    epsij[ "lj" "N" "b" ] = 0.2495 * FE_vdW_coeff
    epsij[ "lj" "N" "I" ] = 0.2972 * FE_vdW_coeff
    epsij[ "lj" "N" "M" ] = 0.3742 * FE_vdW_coeff
    epsij[ "lj" "N" "X" ] = 0.1600 * FE_vdW_coeff

    epsij[ "lj" "O" "C" ] = 0.1732 * FE_vdW_coeff
    epsij[ "lj" "O" "N" ] = 0.1789 * FE_vdW_coeff
    epsij[ "lj" "O" "O" ] = 0.2000 * FE_vdW_coeff
    epsij[ "lj" "O" "P" ] = 0.2000 * FE_vdW_coeff
    epsij[ "lj" "O" "S" ] = 0.2000 * FE_vdW_coeff
    epsij[ "lj" "O" "H" ] = 0.0632 * FE_vdW_coeff
    epsij[ "lj" "O" "f" ] = 0.0447 * FE_vdW_coeff
    epsij[ "lj" "O" "F" ] = 0.1265 * FE_vdW_coeff
    epsij[ "lj" "O" "c" ] = 0.2349 * FE_vdW_coeff
    epsij[ "lj" "O" "b" ] = 0.2789 * FE_vdW_coeff
    epsij[ "lj" "O" "I" ] = 0.3323 * FE_vdW_coeff
    epsij[ "lj" "O" "M" ] = 0.4183 * FE_vdW_coeff
    epsij[ "lj" "O" "X" ] = 0.1789 * FE_vdW_coeff

    epsij[ "lj" "P" "C" ] = 0.1732 * FE_vdW_coeff
    epsij[ "lj" "P" "N" ] = 0.1789 * FE_vdW_coeff
    epsij[ "lj" "P" "O" ] = 0.2000 * FE_vdW_coeff
    epsij[ "lj" "P" "P" ] = 0.2000 * FE_vdW_coeff
    epsij[ "lj" "P" "S" ] = 0.2000 * FE_vdW_coeff
    epsij[ "lj" "P" "H" ] = 0.0632 * FE_vdW_coeff
    epsij[ "lj" "P" "f" ] = 0.0447 * FE_vdW_coeff
    epsij[ "lj" "P" "F" ] = 0.1265 * FE_vdW_coeff
    epsij[ "lj" "P" "c" ] = 0.2349 * FE_vdW_coeff
    epsij[ "lj" "P" "b" ] = 0.2789 * FE_vdW_coeff
    epsij[ "lj" "P" "I" ] = 0.3323 * FE_vdW_coeff
    epsij[ "lj" "P" "M" ] = 0.4183 * FE_vdW_coeff
    epsij[ "lj" "P" "X" ] = 0.1789 * FE_vdW_coeff

    epsij[ "lj" "S" "C" ] = 0.1732 * FE_vdW_coeff
    epsij[ "lj" "S" "N" ] = 0.1789 * FE_vdW_coeff
    epsij[ "lj" "S" "O" ] = 0.2000 * FE_vdW_coeff
    epsij[ "lj" "S" "P" ] = 0.2000 * FE_vdW_coeff
    epsij[ "lj" "S" "S" ] = 0.2000 * FE_vdW_coeff
    epsij[ "lj" "S" "H" ] = 0.0632 * FE_vdW_coeff
    epsij[ "lj" "S" "f" ] = 0.0447 * FE_vdW_coeff
    epsij[ "lj" "S" "F" ] = 0.1265 * FE_vdW_coeff
    epsij[ "lj" "S" "c" ] = 0.2349 * FE_vdW_coeff
    epsij[ "lj" "S" "b" ] = 0.2789 * FE_vdW_coeff
    epsij[ "lj" "S" "I" ] = 0.3323 * FE_vdW_coeff
    epsij[ "lj" "S" "M" ] = 0.4183 * FE_vdW_coeff
    epsij[ "lj" "S" "X" ] = 0.1789 * FE_vdW_coeff

    epsij[ "lj" "H" "C" ] = 0.0548 * FE_vdW_coeff
    epsij[ "lj" "H" "N" ] = 0.0566 * FE_vdW_coeff
    epsij[ "lj" "H" "O" ] = 0.0632 * FE_vdW_coeff
    epsij[ "lj" "H" "P" ] = 0.0632 * FE_vdW_coeff
    epsij[ "lj" "H" "S" ] = 0.0632 * FE_vdW_coeff
    epsij[ "lj" "H" "H" ] = 0.0200 * FE_vdW_coeff
    epsij[ "lj" "H" "f" ] = 0.0141 * FE_vdW_coeff
    epsij[ "lj" "H" "F" ] = 0.0400 * FE_vdW_coeff
    epsij[ "lj" "H" "c" ] = 0.0743 * FE_vdW_coeff
    epsij[ "lj" "H" "b" ] = 0.0882 * FE_vdW_coeff
    epsij[ "lj" "H" "I" ] = 0.1051 * FE_vdW_coeff
    epsij[ "lj" "H" "M" ] = 0.1323 * FE_vdW_coeff
    epsij[ "lj" "H" "X" ] = 0.0566 * FE_vdW_coeff

    epsij[ "lj" "f" "C" ] = 0.0387 * FE_vdW_coeff
    epsij[ "lj" "f" "N" ] = 0.0400 * FE_vdW_coeff
    epsij[ "lj" "f" "O" ] = 0.0447 * FE_vdW_coeff
    epsij[ "lj" "f" "P" ] = 0.0447 * FE_vdW_coeff
    epsij[ "lj" "f" "S" ] = 0.0447 * FE_vdW_coeff
    epsij[ "lj" "f" "H" ] = 0.0141 * FE_vdW_coeff
    epsij[ "lj" "f" "f" ] = 0.0100 * FE_vdW_coeff
    epsij[ "lj" "f" "F" ] = 0.0283 * FE_vdW_coeff
    epsij[ "lj" "f" "c" ] = 0.0525 * FE_vdW_coeff
    epsij[ "lj" "f" "b" ] = 0.0624 * FE_vdW_coeff
    epsij[ "lj" "f" "I" ] = 0.0743 * FE_vdW_coeff
    epsij[ "lj" "f" "M" ] = 0.0935 * FE_vdW_coeff
    epsij[ "lj" "f" "X" ] = 0.0400 * FE_vdW_coeff

    epsij[ "lj" "F" "C" ] = 0.1095 * FE_vdW_coeff
    epsij[ "lj" "F" "N" ] = 0.1131 * FE_vdW_coeff
    epsij[ "lj" "F" "O" ] = 0.1265 * FE_vdW_coeff
    epsij[ "lj" "F" "P" ] = 0.1265 * FE_vdW_coeff
    epsij[ "lj" "F" "S" ] = 0.1265 * FE_vdW_coeff
    epsij[ "lj" "F" "H" ] = 0.0400 * FE_vdW_coeff
    epsij[ "lj" "F" "f" ] = 0.0283 * FE_vdW_coeff
    epsij[ "lj" "F" "F" ] = 0.0800 * FE_vdW_coeff
    epsij[ "lj" "F" "c" ] = 0.1486 * FE_vdW_coeff
    epsij[ "lj" "F" "b" ] = 0.1764 * FE_vdW_coeff
    epsij[ "lj" "F" "I" ] = 0.2101 * FE_vdW_coeff
    epsij[ "lj" "F" "M" ] = 0.2646 * FE_vdW_coeff
    epsij[ "lj" "F" "X" ] = 0.1131 * FE_vdW_coeff

    epsij[ "lj" "c" "C" ] = 0.2035 * FE_vdW_coeff
    epsij[ "lj" "c" "N" ] = 0.2101 * FE_vdW_coeff
    epsij[ "lj" "c" "O" ] = 0.2349 * FE_vdW_coeff
    epsij[ "lj" "c" "P" ] = 0.2349 * FE_vdW_coeff
    epsij[ "lj" "c" "S" ] = 0.2349 * FE_vdW_coeff
    epsij[ "lj" "c" "H" ] = 0.0743 * FE_vdW_coeff
    epsij[ "lj" "c" "f" ] = 0.0525 * FE_vdW_coeff
    epsij[ "lj" "c" "F" ] = 0.1486 * FE_vdW_coeff
    epsij[ "lj" "c" "c" ] = 0.2760 * FE_vdW_coeff
    epsij[ "lj" "c" "b" ] = 0.3277 * FE_vdW_coeff
    epsij[ "lj" "c" "I" ] = 0.3903 * FE_vdW_coeff
    epsij[ "lj" "c" "M" ] = 0.4914 * FE_vdW_coeff
    epsij[ "lj" "c" "X" ] = 0.2101 * FE_vdW_coeff

    epsij[ "lj" "b" "C" ] = 0.2416 * FE_vdW_coeff
    epsij[ "lj" "b" "N" ] = 0.2495 * FE_vdW_coeff
    epsij[ "lj" "b" "O" ] = 0.2789 * FE_vdW_coeff
    epsij[ "lj" "b" "P" ] = 0.2789 * FE_vdW_coeff
    epsij[ "lj" "b" "S" ] = 0.2789 * FE_vdW_coeff
    epsij[ "lj" "b" "H" ] = 0.0882 * FE_vdW_coeff
    epsij[ "lj" "b" "f" ] = 0.0624 * FE_vdW_coeff
    epsij[ "lj" "b" "F" ] = 0.1764 * FE_vdW_coeff
    epsij[ "lj" "b" "c" ] = 0.3277 * FE_vdW_coeff
    epsij[ "lj" "b" "b" ] = 0.3890 * FE_vdW_coeff
    epsij[ "lj" "b" "I" ] = 0.4634 * FE_vdW_coeff
    epsij[ "lj" "b" "M" ] = 0.5834 * FE_vdW_coeff
    epsij[ "lj" "b" "X" ] = 0.2495 * FE_vdW_coeff

    epsij[ "lj" "I" "C" ] = 0.2877 * FE_vdW_coeff
    epsij[ "lj" "I" "N" ] = 0.2972 * FE_vdW_coeff
    epsij[ "lj" "I" "O" ] = 0.3323 * FE_vdW_coeff
    epsij[ "lj" "I" "P" ] = 0.3323 * FE_vdW_coeff
    epsij[ "lj" "I" "S" ] = 0.3323 * FE_vdW_coeff
    epsij[ "lj" "I" "H" ] = 0.1051 * FE_vdW_coeff
    epsij[ "lj" "I" "f" ] = 0.0743 * FE_vdW_coeff
    epsij[ "lj" "I" "F" ] = 0.2101 * FE_vdW_coeff
    epsij[ "lj" "I" "c" ] = 0.3903 * FE_vdW_coeff
    epsij[ "lj" "I" "b" ] = 0.4634 * FE_vdW_coeff
    epsij[ "lj" "I" "I" ] = 0.5520 * FE_vdW_coeff
    epsij[ "lj" "I" "M" ] = 0.6950 * FE_vdW_coeff
    epsij[ "lj" "I" "X" ] = 0.2972 * FE_vdW_coeff

    epsij[ "lj" "M" "C" ] = 0.3623 * FE_vdW_coeff
    epsij[ "lj" "M" "N" ] = 0.3742 * FE_vdW_coeff
    epsij[ "lj" "M" "O" ] = 0.4183 * FE_vdW_coeff
    epsij[ "lj" "M" "P" ] = 0.4183 * FE_vdW_coeff
    epsij[ "lj" "M" "S" ] = 0.4183 * FE_vdW_coeff
    epsij[ "lj" "M" "H" ] = 0.1323 * FE_vdW_coeff
    epsij[ "lj" "M" "f" ] = 0.0935 * FE_vdW_coeff
    epsij[ "lj" "M" "F" ] = 0.2646 * FE_vdW_coeff
    epsij[ "lj" "M" "c" ] = 0.4914 * FE_vdW_coeff
    epsij[ "lj" "M" "b" ] = 0.5834 * FE_vdW_coeff
    epsij[ "lj" "M" "I" ] = 0.6950 * FE_vdW_coeff
    epsij[ "lj" "M" "M" ] = 0.8750 * FE_vdW_coeff
    epsij[ "lj" "M" "X" ] = 0.3742 * FE_vdW_coeff

    epsij[ "lj" "X" "C" ] = 0.1549 * FE_vdW_coeff
    epsij[ "lj" "X" "N" ] = 0.1600 * FE_vdW_coeff
    epsij[ "lj" "X" "O" ] = 0.1789 * FE_vdW_coeff
    epsij[ "lj" "X" "P" ] = 0.1789 * FE_vdW_coeff
    epsij[ "lj" "X" "S" ] = 0.1789 * FE_vdW_coeff
    epsij[ "lj" "X" "H" ] = 0.0566 * FE_vdW_coeff
    epsij[ "lj" "X" "f" ] = 0.0400 * FE_vdW_coeff
    epsij[ "lj" "X" "F" ] = 0.1131 * FE_vdW_coeff
    epsij[ "lj" "X" "c" ] = 0.2101 * FE_vdW_coeff
    epsij[ "lj" "X" "b" ] = 0.2495 * FE_vdW_coeff
    epsij[ "lj" "X" "I" ] = 0.2972 * FE_vdW_coeff
    epsij[ "lj" "X" "M" ] = 0.3742 * FE_vdW_coeff
    epsij[ "lj" "X" "X" ] = 0.1600 * FE_vdW_coeff

    epsij[ "lj" "C" "A" ] = 0.1500 * FE_vdW_coeff
    epsij[ "lj" "A" "C" ] = epsij[ "lj" "C" "A" ]
    epsij[ "lj" "A" "A" ] = epsij[ "lj" "C" "C" ]
    epsij[ "lj" "A" "N" ] = epsij[ "lj" "C" "N" ]
    epsij[ "lj" "A" "O" ] = epsij[ "lj" "C" "O" ]
    epsij[ "lj" "A" "S" ] = epsij[ "lj" "C" "S" ]
    epsij[ "lj" "A" "H" ] = epsij[ "lj" "C" "H" ]
    epsij[ "lj" "N" "A" ] = epsij[ "lj" "A" "N" ]
    epsij[ "lj" "O" "A" ] = epsij[ "lj" "A" "O" ]
    epsij[ "lj" "S" "A" ] = epsij[ "lj" "A" "S" ]
    epsij[ "lj" "H" "A" ] = epsij[ "lj" "A" "H" ]
    epsij[ "lj" "A" "X" ] = epsij[ "lj" "C" "X" ]
    epsij[ "lj" "A" "X" ] = epsij[ "lj" "C" "X" ]
    epsij[ "lj" "X" "A" ] = epsij[ "lj" "A" "X" ]

    #
    # Hydrogen-bonding parameters
    #
    Rij[ "hb" "N" "H" ] = 1.90
    Rij[ "hb" "O" "H" ] = 1.90
    Rij[ "hb" "S" "H" ] = 2.50
    Rij[ "hb" "H" "N" ] = 1.90
    Rij[ "hb" "H" "O" ] = 1.90
    Rij[ "hb" "H" "S" ] = 2.50

    #
    # AutoDock Binding Free Energy Model 140n
    # New well-depths multiplied by the hbond.difference
    # coefficient, 0.0656
    #

    #
    # Original enthalpic well-depths for hydrogen-bonding...
    #
    epsij[ "hb" "N" "H" ] = 5.0 * FE_hbond_coeff
    epsij[ "hb" "O" "H" ] = 5.0 * FE_hbond_coeff
    epsij[ "hb" "S" "H" ] = 1.0 * FE_hbond_coeff
    epsij[ "hb" "H" "N" ] = 5.0 * FE_hbond_coeff
    epsij[ "hb" "H" "O" ] = 5.0 * FE_hbond_coeff
    epsij[ "hb" "H" "S" ] = 1.0 * FE_hbond_coeff

}
$1 ~ /ATOM|HETATM|atom|hetatm/ {
#
#   Recognizable atom types are C,A,N,O,S,P & H
#   and...                      f,F,c,b,I
#   and...                      X,M
#   (note: A is aromatic carbon)
#   (f = iron, F=Fluorine, c=Chlorine, b=Bromine, I=iodine)
#   It is assumed that the 12-6 parameters of C can be used for P...
#
    card = substr($0,1,6)
    anum = substr($0,7,5)
    aname = substr($0,13,4)
    altloc = substr($0,17,1)
    resname = substr($0,18,3)
    chainid = substr($0,22,1)
    resnum = substr($0,23,4)
    inscode = substr($0,27,1)
    x = substr($0,31,8)
    y = substr($0,39,8)
    z = substr($0,47,8)
    occ = substr($0,55,6)
    tempfac = substr($0,61,6)
    footnot = substr($0,67,4)
    charge = substr($0,71,6)
    volume = substr($0,77,8)
    solpar = substr($0,85,8)

    pdbaname = aname      # Keep original format for output...
    if (substr(aname,1,1) == " ") {    # Delete the first blank: -xxx -> xxx
        aname = substr(aname,2,3)
    }
    if (substr(aname,4,1) == " ") {    # Delete the last blank: xxx- -> xxx
        aname = substr(aname,1,3)
    }
    if (substr(aname,3,1) == " ") {    # Delete the last blank: xx- -> xx
        aname = substr(aname,1,2)
    }
    if (substr(aname,2,1) == " ") {    # Delete the last blank: x- -> x
        aname = substr(aname,1,1)
    }
    #
    # Extract the 1-letter atom type code from the atom name in the PDB* file
    #
    atype_lig = substr(aname, 1,1)
    n[atype_lig]++
}
END {
    print "receptor <macromol>.pdbqs                #macromolecule"
    print "gridfld  <macromol>.maps.fld                #grid_data_file"
    print "npts     80 80 80                #num.grid points in xyz"
    print "spacing  0.375                        #spacing (Angstroms)"
    print "gridcenter <xc> <yc> <zc>                #center_of_grids or auto"
    printf("types ")
    for (i = 1; i <= NUM_TYPES; i++) {
        type = substr(ALL_TYPES,i,1)  ## Note: type is a character, not int!
        if (n[type] != 0) {
          printf("%1s",type)
        }
    }
    printf("                        #atom type names\n")
    printf("smooth 0.500\t\t\t#store minimum energy within radius (Angstroms)\n")

    for (a_lig = 1; a_lig <= NUM_TYPES; a_lig++) {
        atype_lig = substr(ALL_TYPES, a_lig,1)
        if (n[atype_lig] != 0) {

            printf ("map <macromol>.%s.map                        #filename of grid map\n",atype_lig)

            ## Rebecca Wade email: Thu, 20 Apr 2000
            ## RebeccaWade if (atype_lig == "A") { # some lines for "A" are not here yet.
            ## RebeccaWade                atype_lig = "C"
            ## RebeccaWade }
#            Note: types N,O,S can H-bond...
#            But: nitrogen in >N-H, as in amides, has no free lone pairs, 
#            so CANNOT accept H-bonds!

            if ((atype_lig == "O")||(atype_lig == "S")) {
                set_hb_acc_1 = ON
            } else {
                set_hb_acc_1 = OFF
            }
            if (atype_lig == "H") {
                set_hb_don_1 = ON
            } else {
                set_hb_don_1 = OFF
            }

            for (a_pro = 1; a_pro <= length(PROTEIN_ATOMTYPES); a_pro++) {
                atype_pro = substr(PROTEIN_ATOMTYPES, a_pro, 1)
                bond      = "lj"
                exponent1 =  12
                exponent2 =   6
                if ( ((set_hb_acc_1 == ON) && (atype_pro == "H")) ||
                ((set_hb_don_1 == ON) && ((atype_pro == "O")||(atype_pro == "S"))) ) {
                    bond      = "hb"
                    exponent1 =  12
                    exponent2 =  10
                }

                printf ("nbp_r_eps %5.2f %9.7f %2d %2d\t#%1s-%1s %s\n", \
                Rij[ bond atype_lig atype_pro ], epsij[ bond atype_lig atype_pro ], \
                exponent1, exponent2, atype_lig, atype_pro, bond )
            } #for a_pro

            printf("sol_par %5.2f %6.4f                #%1s atomic fragmental volume, solvation param.\n", SolVol[ atype_lig ], SolPar[ atype_lig ], atype_lig)
            printf("constant %5.3f                        #%1s grid map constant energy\n", SolCon[ atype_lig ], atype_lig)
        } #if natype_lig!=0
    } #for a_lig

    print "elecmap <macromol>.e.map                #electrostatic potential map"
    printf("dielectric %.4f                #<0,distance-dep.diel; >0,constant\n", -FE_estat_coeff) # minus is needed
    print "#fmap <macromol>.f.map                #floating grid"
    print "# gpf3gen.awk 3.0.4 #"
}
